summaryrefslogtreecommitdiffstats
path: root/src/settings.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:18:28 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:18:28 -0600
commit934db26c3f8efe148a5680c22f965ee10f818a61 (patch)
tree4a47cbb3ef398d11fa9283b5afdcd0a8d84fad7c /src/settings.h
parenta1fb52e00e362130a46b34570e53f2c1f322f373 (diff)
downloadbasket-934db26c3f8efe148a5680c22f965ee10f818a61.tar.gz
basket-934db26c3f8efe148a5680c22f965ee10f818a61.zip
Rename KGlobal, KProcess, and KClipboard to avoid conflicts with KDE4
Diffstat (limited to 'src/settings.h')
-rw-r--r--src/settings.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/settings.h b/src/settings.h
index b593b96..1f45bbf 100644
--- a/src/settings.h
+++ b/src/settings.h
@@ -42,7 +42,7 @@ class TQGroupBox;
class TQButtonGroup;
class KColorCombo;
class KIntNumInput;
-class KGlobalAccel;
+class TDEGlobalAccel;
class TQLabel;
class Container;
@@ -270,7 +270,7 @@ class Settings // FIXME: Distaptch new config events ?
static inline bool showOnMouseIn() { return s_showOnMouseIn; }
static inline int timeToShowOnMouseIn() { return s_timeToShowOnMouseIn; }
static inline int basketTreeWidth() { return s_basketTreeWidth; }
- static inline int dropTimeToShow() { return 7; } // TODO: 700 ; TODO: There is certainly a KGlobalConfig ???
+ static inline int dropTimeToShow() { return 7; } // TODO: 700 ; TODO: There is certainly a TDEGlobalConfig ???
static inline bool usePassivePopup() { return s_usePassivePopup; }
static inline bool welcomeBasketsAdded() { return s_welcomeBasketsAdded; }
static inline TQString dataFolder() { return s_dataFolder; }